@@ -2,4 +2,4 @@ from plugin import OAuthPlugin
 
 from managers import DefaultManager
 
-from model import Consumer
+from model import Consumer, RequestToken, AccessToken
